==> jss-3.5.0.tgz: package/docs/external-projects.md <==
## Projects created by community based on jss.

### JSS Plugins

[jss-vendor-prefixer-ie10](https://github.com/alexkuz/jss-vendor-prefixer-ie10) JSS plugin that handles vendor prefixes for the legacy browsers.

### Convenience

[jss-simple](https://github.com/ashaffer/jss-simple) Thin wrapper around jss that simplifies its interface and restricts you to a single, global stylesheet.

[jss-css](https://github.com/alexkuz/jss-css) This is a convenience module for JSS that converts CSS string into JSS object. It allows to describe style classes for components in a habitual and little less verbose way.

### Layout systems

[perdido](https://github.com/wldcordeiro/perdido) JSS fractional grid system built with calc(), based on Lost PostCSS grid. Supports masonry, vertical, and waffle grids.

### Babel plugins

[babel-plugin-jss-simple](https://github.com/ashaffer/babel-plugin-jss-simple) Add filename keys to your jss-simple declarations to help with hot reloading.

[babel-plugin-jss-css](https://github.com/alexkuz/babel-plugin-jss-css) Babel plugin for [jss-css](https://github.com/alexkuz/jss-css) module.

### Webpack loaders

[jss-loader](https://github.com/markdalgleish/jss-loader) Use JavaScript as your CSS preprocessor!


### Demos

[css-modules-jss-demo](https://github.com/markdalgleish/css-modules-jss-demo) An experimental demo of CSS Modules, using JSS via jss-loader to compile JavaScript into locally scoped CSS.

[perdido](http://jsstyles.github.io/examples/perdido/index.html) Demo of perdido fractional grid system.

### UI libs

[react-modal-dialog](https://github.com/qimingweng/react-modal-dialog) A modal dialog for ReactJS

==> jss-3.6.1.tgz: package/docs/external-projects.md <==
## Projects created by community based on jss.

### JSS Plugins

[jss-vendor-prefixer-ie10](https://github.com/alexkuz/jss-vendor-prefixer-ie10) JSS plugin that handles vendor prefixes for the legacy browsers.

[jss-legacy-browsers](https://github.com/moliver-bb/jss-legacy-browsers) JSS plugin that handles legacy browser support

[jss-color-rebeccapurple](https://github.com/joshgillies/jss-color-rebeccapurple) JSS plugin to transform the W3C CSS rebeccapurple color to rgb.

### Convenience

[jss-simple](https://github.com/ashaffer/jss-simple) Thin wrapper around jss that simplifies its interface and restricts you to a single, global stylesheet.

[jss-css](https://github.com/alexkuz/jss-css) This is a convenience module for JSS that converts CSS string into JSS object. It allows to describe style classes for components in a habitual and little less verbose way.

### Layout systems

[perdido](https://github.com/wldcordeiro/perdido) JSS fractional grid system built with calc(), based on Lost PostCSS grid. Supports masonry, vertical, and waffle grids.

### Build tools integrations

[babel-plugin-jss-simple](https://github.com/ashaffer/babel-plugin-jss-simple) Add filename keys to your jss-simple declarations to help with hot reloading.

[babel-plugin-jss-css](https://github.com/alexkuz/babel-plugin-jss-css) Babel plugin for 

[jss-css](https://github.com/alexkuz/jss-css) module.

[jss-loader](https://github.com/markdalgleish/jss-loader) Webpack loader - use JavaScript as your CSS preprocessor!

[gulp-jss](https://github.com/gooy/gulp-jss) Gulp plugin

### Demos

[css-modules-jss-demo](https://github.com/markdalgleish/css-modules-jss-demo) An experimental demo of CSS Modules, using JSS via jss-loader to compile JavaScript into locally scoped CSS.

[perdido](http://jsstyles.github.io/examples/perdido/index.html) Demo of perdido fractional grid system.

### UI libs

[react-modal-dialog](https://github.com/qimingweng/react-modal-dialog) A modal dialog for ReactJS
